<?php
/*
Plugin Name: Hurda Fiyatları Client
Plugin URI: https://aylahurda.com
Description: Ayla Hurda API entegrasyonu ile hurda fiyatlarını sitenizde gösterin
Version: 1.0
Author: Ayla Hurda
*/

// Güvenlik kontrolü
defined('ABSPATH') or die('Bu dosyaya doğrudan erişim engellendi.');

class HurdaFiyatlariClient {
    private $options;
    private $cache_time = 3600; // 1 saat cache
    
    public function __construct() {
        $this->options = get_option('hurda_fiyatlari_client_ayarlar');
        
        // Admin menüsü
        add_action('admin_menu', array($this, 'admin_menu_olustur'));
        add_action('admin_init', array($this, 'ayarlari_kaydet'));
        
        // Shortcode ve widget
        add_shortcode('hurda_fiyatlari_client', array($this, 'fiyat_listesi_shortcode'));
        add_action('widgets_init', function() {
            register_widget('Hurda_Fiyatlari_Widget');
        });
        
        // AJAX fiyat güncelleme
        add_action('wp_ajax_hurda_fiyatlari_guncelle', array($this, 'fiyatlari_guncelle'));
        
        // CSS ve JS
        add_action('wp_enqueue_scripts', array($this, 'frontend_scripts'));
        add_action('admin_enqueue_scripts', array($this, 'admin_scripts'));
    }
    
    // Admin menüsü
    public function admin_menu_olustur() {
        add_menu_page(
            'Hurda Fiyatları Client',
            'Hurda Fiyatları',
            'manage_options',
            'hurda-fiyatlari-client',
            array($this, 'admin_sayfa'),
            'dashicons-chart-area',
            30
        );
    }
    
    // Admin sayfası
    public function admin_sayfa() {
        $options = $this->options;
        $last_update = get_transient('hurda_fiyatlari_last_update');
        $fiyatlar = get_transient('hurda_fiyatlari_cache');
        ?>
        <div class="wrap">
            <h1>Hurda Fiyatları Ayarları</h1>
            
            <?php if (isset($_GET['settings-updated'])): ?>
                <div class="notice notice-success">
                    <p>Ayarlar kaydedildi.</p>
                </div>
            <?php endif; ?>
            
            <div class="card">
                <h2>API Bağlantı Ayarları</h2>
                <form method="post" action="options.php">
                    <?php settings_fields('hurda_fiyatlari_client_ayarlar'); ?>
                    
                    <table class="form-table">
                        <tr>
                            <th scope="row">API Anahtarı</th>
                            <td>
                                <input type="text" name="hurda_fiyatlari_client_ayarlar[api_key]" 
                                       value="<?php echo esc_attr($options['api_key'] ?? ''); ?>" 
                                       class="regular-text">
                                <p class="description">
                                    API anahtarınızı <a href="https://aylahurda.com/api-kayit" 
                                    target="_blank">buradan alabilirsiniz</a>
                                </p>
                            </td>
                        </tr>
                        <tr>
                            <th scope="row">Otomatik Güncelleme</th>
                            <td>
                                <select name="hurda_fiyatlari_client_ayarlar[guncelleme_siklik]">
                                    <option value="hourly" <?php selected($options['guncelleme_siklik'] ?? '', 'hourly'); ?>>
                                        Saatlik
                                    </option>
                                    <option value="twicedaily" <?php selected($options['guncelleme_siklik'] ?? '', 'twicedaily'); ?>>
                                        Günde 2 Kez
                                    </option>
                                    <option value="daily" <?php selected($options['guncelleme_siklik'] ?? '', 'daily'); ?>>
                                        Günlük
                                    </option>
                                </select>
                            </td>
                        </tr>
                    </table>
                    
                    <?php submit_button(); ?>
                </form>
            </div>
            
            <div class="card">
                <h2>Mevcut Fiyatlar</h2>
                <?php if ($last_update): ?>
                    <p>Son güncelleme: <?php echo date('d.m.Y H:i', $last_update); ?></p>
                <?php endif; ?>
                
                <button class="button button-primary manuel-guncelle">
                    Fiyatları Güncelle
                </button>
                
                <?php if ($fiyatlar): ?>
                    <table class="wp-list-table widefat fixed striped">
                        <thead>
                            <tr>
                                <th>Hurda Türü</th>
                                <th>Fiyat</th>
                                <th>Birim</th>
                                <th>Son Güncelleme</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php foreach ($fiyatlar as $fiyat): ?>
                                <tr>
                                    <td><?php echo esc_html($fiyat->hurda_turu); ?></td>
                                    <td><?php echo number_format($fiyat->fiyat, 2); ?></td>
                                    <td><?php echo esc_html($fiyat->birim); ?></td>
                                    <td><?php echo date('d.m.Y H:i', strtotime($fiyat->son_guncelleme)); ?></td>
                                </tr>
                            <?php endforeach; ?>
                        </tbody>
                    </table>
                <?php else: ?>
                    <p>Henüz fiyat verisi yok. Lütfen API anahtarınızı girin ve fiyatları güncelleyin.</p>
                <?php endif; ?>
            </div>
            
            <div class="card">
                <h2>Kullanım</h2>
                <p>Fiyatları göstermek için aşağıdaki shortcode'u kullanabilirsiniz:</p>
                <code>[hurda_fiyatlari_client]</code>
                
                <p>Belirli bir hurda türü için:</p>
                <code>[hurda_fiyatlari_client tur="Bakır"]</code>
                
                <p>Kart görünümü için:</p>
                <code>[hurda_fiyatlari_client style="cards"]</code>
            </div>
        </div>

        <script>
        jQuery(document).ready(function($) {
            $('.manuel-guncelle').click(function() {
                var button = $(this);
                button.prop('disabled', true).text('Güncelleniyor...');
                
                $.post(ajaxurl, {
                    action: 'hurda_fiyatlari_guncelle',
                    nonce: '<?php echo wp_create_nonce('hurda_fiyatlari_guncelle'); ?>'
                }, function(response) {
                    if (response.success) {
                        location.reload();
                    } else {
                        alert('Hata: ' + response.data.message);
                        button.prop('disabled', false).text('Fiyatları Güncelle');
                    }
                });
            });
        });
        </script>
        <?php
    }
    
    // Ayarları kaydet
    public function ayarlari_kaydet() {
        register_setting('hurda_fiyatlari_client_ayarlar', 'hurda_fiyatlari_client_ayarlar');
    }
    
    // Fiyatları API'den çek
    public function fiyatlari_guncelle() {
        check_ajax_referer('hurda_fiyatlari_guncelle', 'nonce');
        
        if (!current_user_can('manage_options')) {
            wp_send_json_error(array('message' => 'Yetkiniz yok.'));
        }
        
        $api_key = $this->options['api_key'] ?? '';
        if (empty($api_key)) {
            wp_send_json_error(array('message' => 'API anahtarı gerekli.'));
        }
        
        $response = wp_remote_get('https://aylahurda.com/wp-json/hurda/v1/fiyatlar', array(
            'headers' => array(
                'X-API-Key' => $api_key
            )
        ));
        
        if (is_wp_error($response)) {
            wp_send_json_error(array('message' => $response->get_error_message()));
        }
        
        $body = wp_remote_retrieve_body($response);
        $data = json_decode($body);
        
        if (!$data || !$data->success) {
            wp_send_json_error(array('message' => 'API yanıtı geçersiz.'));
        }
        
        // Cache'i güncelle
        set_transient('hurda_fiyatlari_cache', $data->data, $this->cache_time);
        set_transient('hurda_fiyatlari_last_update', time(), $this->cache_time);
        
        wp_send_json_success();
    }
    
    // Frontend için shortcode
    public function fiyat_listesi_shortcode($atts) {
        $atts = shortcode_atts(array(
            'tur' => '',
            'style' => 'table',
            'limit' => -1
        ), $atts);
        
        $fiyatlar = get_transient('hurda_fiyatlari_cache');
        if (!$fiyatlar) {
            return '<p>Fiyat verileri henüz yüklenmemiş.</p>';
        }
        
        // Filtrele
        if (!empty($atts['tur'])) {
            $fiyatlar = array_filter($fiyatlar, function($fiyat) use ($atts) {
                return $fiyat->hurda_turu === $atts['tur'];
            });
        }
        
        ob_start();
        ?>
        <div class="hurda-fiyatlari-client <?php echo esc_attr($atts['style']); ?>">
            <?php if ($atts['style'] === 'table'): ?>
                <table class="hurda-fiyat-tablosu">
                    <thead>
                        <tr>
                            <th>Hurda Türü</th>
                            <th>Fiyat</th>
                            <th>Birim</th>
                            <th>Son Güncelleme</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php foreach ($fiyatlar as $fiyat): ?>
                            <tr>
                                <td><?php echo esc_html($fiyat->hurda_turu); ?></td>
                                <td><?php echo number_format($fiyat->fiyat, 2); ?></td>
                                <td><?php echo esc_html($fiyat->birim); ?></td>
                                <td><?php echo date('d.m.Y H:i', strtotime($fiyat->son_guncelleme)); ?></td>
                            </tr>
                        <?php endforeach; ?>
                    </tbody>
                </table>
            <?php else: ?>
                <div class="hurda-fiyat-kartlari">
                    <?php foreach ($fiyatlar as $fiyat): ?>
                        <div class="hurda-fiyat-kart">
                            <h3><?php echo esc_html($fiyat->hurda_turu); ?></h3>
                            <div class="fiyat">
                                <?php echo number_format($fiyat->fiyat, 2); ?>
                                <span class="birim"><?php echo esc_html($fiyat->birim); ?></span>
                            </div>
                            <div class="guncelleme">
                                Son güncelleme: <?php echo date('d.m.Y H:i', strtotime($fiyat->son_guncelleme)); ?>
                            </div>
                        </div>
                    <?php endforeach; ?>
                </div>
            <?php endif; ?>
        </div>
        <?php
        return ob_get_clean();
    }
    
    // Frontend stil ve scriptleri
    public function frontend_scripts() {
        wp_enqueue_style(
            'hurda-fiyatlari-client',
            plugins_url('css/frontend.css', __FILE__)
        );
    }
    
    // Admin stil ve scriptleri
    public function admin_scripts($hook) {
        if ($hook !== 'toplevel_page_hurda-fiyatlari-client') {
            return;
        }
        
        wp_enqueue_style(
            'hurda-fiyatlari-client-admin',
            plugins_url('css/admin.css', __FILE__)
        );
    }
}

// Eklentiyi başlat
new HurdaFiyatlariClient();

// Widget sınıfı
class Hurda_Fiyatlari_Widget extends WP_Widget {
    public function __construct() {
        parent::__construct(
            'hurda_fiyatlari_widget',
            'Hurda Fiyatları',
            array('description' => 'Hurda fiyatlarını gösterir')
        );
    }

    public function widget($args, $instance) {
        echo $args['before_widget'];
        if (!empty($instance['title'])) {
            echo $args['before_title'] . apply_filters('widget_title', $instance['title']) . $args['after_title'];
        }
        
        echo do_shortcode('[hurda_fiyatlari_client style="' . ($instance['style'] ?? 'table') . '"]');
        
        echo $args['after_widget'];
    }

    public function form($instance) {
        $title = $instance['title'] ?? '';
        $style = $instance['style'] ?? 'table';
        ?>
        <p>
            <label for="<?php echo $this->get_field_id('title'); ?>">Başlık:</label>
            <input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" 
                   name="<?php echo $this->get_field_name('title'); ?>" type="text" 
                   value="<?php echo esc_attr($title); ?>">
        </p>
        <p>
            <label for="<?php echo $this->get_field_id('style'); ?>">Görünüm:</label><select class="widefat" id="<?php echo $this->get_field_id('style'); ?>" 
                    name="<?php echo $this->get_field_name('style'); ?>">
                <option value="table" <?php selected($style, 'table'); ?>>Tablo</option>
                <option value="cards" <?php selected($style, 'cards'); ?>>Kartlar</option>
            </select>
        </p>
        <?php
    }

    public function update($new_instance, $old_instance) {
        $instance = array();
        $instance['title'] = (!empty($new_instance['title'])) ? strip_tags($new_instance['title']) : '';
        $instance['style'] = (!empty($new_instance['style'])) ? strip_tags($new_instance['style']) : 'table';
        return $instance;
    }
}

// CSS dosyalarını oluştur
register_activation_hook(__FILE__, function() {
    // Frontend CSS
    $frontend_css = "
    .hurda-fiyatlari-client {
        max-width: 1200px;
        margin: 2em auto;
        font-family: -apple-system, BlinkMacSystemFont, 'Segoe UI', Roboto, sans-serif;
    }

    .hurda-fiyat-tablosu {
        width: 100%;
        border-collapse: collapse;
        margin-bottom: 1em;
        background: #fff;
        box-shadow: 0 1px 3px rgba(0,0,0,0.1);
    }

    .hurda-fiyat-tablosu th,
    .hurda-fiyat-tablosu td {
        padding: 12px;
        text-align: left;
        border-bottom: 1px solid #eee;
    }

    .hurda-fiyat-tablosu th {
        background: #f8f9fa;
        font-weight: 600;
    }

    .hurda-fiyat-tablosu tr:hover {
        background: #f8f9fa;
    }

    .hurda-fiyat-kartlari {
        display: grid;
        grid-template-columns: repeat(auto-fill, minmax(250px, 1fr));
        gap: 1.5em;
    }

    .hurda-fiyat-kart {
        background: #fff;
        padding: 1.5em;
        border-radius: 8px;
        box-shadow: 0 2px 4px rgba(0,0,0,0.1);
        transition: transform 0.2s ease;
    }

    .hurda-fiyat-kart:hover {
        transform: translateY(-2px);
    }

    .hurda-fiyat-kart h3 {
        margin: 0 0 1em;
        color: #333;
        font-size: 1.2em;
    }

    .hurda-fiyat-kart .fiyat {
        font-size: 1.5em;
        color: #2ecc71;
        margin-bottom: 1em;
    }

    .hurda-fiyat-kart .birim {
        font-size: 0.6em;
        color: #666;
    }

    .hurda-fiyat-kart .guncelleme {
        font-size: 0.8em;
        color: #666;
    }

    @media (max-width: 768px) {
        .hurda-fiyat-tablosu {
            display: block;
            overflow-x: auto;
        }
        
        .hurda-fiyat-kartlari {
            grid-template-columns: 1fr;
        }
    }";

    // Admin CSS
    $admin_css = "
    .hurda-fiyatlari-client-admin .card {
        max-width: 100%;
        margin-top: 20px;
        padding: 20px;
        background: #fff;
        box-shadow: 0 1px 3px rgba(0,0,0,0.1);
    }

    .hurda-fiyatlari-client-admin .notice {
        margin: 20px 0;
    }

    .hurda-fiyatlari-client-admin code {
        display: inline-block;
        padding: 5px 10px;
        background: #f5f5f5;
        border: 1px solid #ddd;
        border-radius: 3px;
        margin: 5px 0;
    }

    .hurda-fiyatlari-client-admin .button.manuel-guncelle {
        margin: 10px 0 20px;
    }";

    // CSS dosyaları için klasör oluştur
    $css_dir = plugin_dir_path(__FILE__) . 'css';
    if (!file_exists($css_dir)) {
        mkdir($css_dir, 0755, true);
    }

    // CSS dosyalarını kaydet
    file_put_contents($css_dir . '/frontend.css', $frontend_css);
    file_put_contents($css_dir . '/admin.css', $admin_css);

    // Varsayılan ayarları oluştur
    add_option('hurda_fiyatlari_client_ayarlar', array(
        'api_key' => '',
        'guncelleme_siklik' => 'hourly'
    ));
});

// Cron ile otomatik güncelleme
add_action('init', function() {
    if (!wp_next_scheduled('hurda_fiyatlari_guncelle_event')) {
        $options = get_option('hurda_fiyatlari_client_ayarlar');
        $schedule = $options['guncelleme_siklik'] ?? 'hourly';
        wp_schedule_event(time(), $schedule, 'hurda_fiyatlari_guncelle_event');
    }
});

add_action('hurda_fiyatlari_guncelle_event', function() {
    $client = new HurdaFiyatlariClient();
    $client->fiyatlari_guncelle();
});

// Eklenti kaldırıldığında temizlik
register_deactivation_hook(__FILE__, function() {
    wp_clear_scheduled_hook('hurda_fiyatlari_guncelle_event');
    delete_transient('hurda_fiyatlari_cache');
    delete_transient('hurda_fiyatlari_last_update');
});

// Client eklentisinin sonuna ekleyin

add_action('wp_ajax_api_kayit_form', 'api_kayit_form_handler');
add_action('wp_ajax_nopriv_api_kayit_form', 'api_kayit_form_handler');

function api_kayit_form_handler() {
    // Nonce kontrolü
    if (!isset($_POST['nonce']) || !wp_verify_nonce($_POST['nonce'], 'api_kayit_nonce')) {
        wp_send_json_error('Güvenlik doğrulaması başarısız');
    }

    // Form verilerini al ve temizle
    $firma_adi = sanitize_text_field($_POST['firma_adi']);
    $email = sanitize_email($_POST['email']);
    $website = esc_url_raw($_POST['website']);
    $telefon = sanitize_text_field($_POST['telefon']);
    $aciklama = sanitize_textarea_field($_POST['aciklama']);

    // Zorunlu alanları kontrol et
    if (empty($firma_adi) || empty($email) || empty($website)) {
        wp_send_json_error('Lütfen tüm zorunlu alanları doldurun');
    }

    // E-posta formatını kontrol et
    if (!is_email($email)) {
        wp_send_json_error('Geçersiz e-posta adresi');
    }

    // Website URL formatını kontrol et
    if (!filter_var($website, FILTER_VALIDATE_URL)) {
        wp_send_json_error('Geçersiz website adresi');
    }

    global $wpdb;
    
    // E-posta veya domain daha önce kayıtlı mı kontrol et
    $mevcut = $wpdb->get_row($wpdb->prepare(
        "SELECT * FROM {$wpdb->prefix}hurda_api_kullanicilari 
         WHERE email = %s OR domain = %s",
        $email, $website
    ));

    if ($mevcut) {
        wp_send_json_error('Bu e-posta adresi veya domain ile daha önce başvuru yapılmış');
    }

    // Yeni API anahtarı oluştur
    $api_anahtar = wp_generate_password(32, false);

    // Veritabanına kaydet
    $sonuc = $wpdb->insert(
        $wpdb->prefix . 'hurda_api_kullanicilari',
        array(
            'firma_adi' => $firma_adi,
            'email' => $email,
            'domain' => $website,
            'telefon' => $telefon,
            'aciklama' => $aciklama,
            'api_anahtar' => $api_anahtar,
            'aktif' => 0,
            'onay_durumu' => 'beklemede',
            'istek_limit' => 1000,
            'olusturma_tarihi' => current_time('mysql')
        ),
        array(
            '%s', '%s', '%s', '%s', '%s', '%s', '%d', '%s', '%d', '%s'
        )
    );

    if ($sonuc === false) {
        wp_send_json_error('Başvuru kaydedilirken bir hata oluştu');
    }

    // Admin'e bildirim e-postası gönder
    $admin_email = get_option('admin_email');
    $konu = 'Yeni API Anahtarı Başvurusu - ' . $firma_adi;
    $mesaj = "Yeni bir API anahtarı başvurusu alındı:\n\n";
    $mesaj .= "Firma Adı: $firma_adi\n";
    $mesaj .= "E-posta: $email\n";
    $mesaj .= "Website: $website\n";
    $mesaj .= "Telefon: $telefon\n";
    $mesaj .= "Açıklama: $aciklama\n\n";
    $mesaj .= "Başvuruyu onaylamak için admin panelini ziyaret edin: \n";
    $mesaj .= admin_url('admin.php?page=hurda-api-basvurulari');

    wp_mail($admin_email, $konu, $mesaj);

    // Başvuran kişiye bilgilendirme e-postası
    $kullanici_konu = 'API Anahtarı Başvurunuz Alındı - Ayla Hurda';
    $kullanici_mesaj = "Sayın $firma_adi,\n\n";
    $kullanici_mesaj .= "API anahtarı başvurunuz başarıyla alınmıştır.\n\n";
    $kullanici_mesaj .= "Başvurunuz incelendikten sonra size e-posta ile bilgi verilecektir.\n\n";
    $kullanici_mesaj .= "Başvuru bilgileriniz:\n";
    $kullanici_mesaj .= "Website: $website\n";
    $kullanici_mesaj .= "Telefon: $telefon\n\n";
    $kullanici_mesaj .= "Sorularınız için bize ulaşabilirsiniz.\n\n";
    $kullanici_mesaj .= "Saygılarımızla,\nAyla Hurda Ekibi";

    wp_mail($email, $kullanici_konu, $kullanici_mesaj);

    // Başarılı yanıt döndür
    wp_send_json_success(array(
        'message' => 'Başvurunuz başarıyla alındı. Lütfen e-posta kutunuzu kontrol edin.',
        'redirect' => home_url('/basvuru-basarili') // İsteğe bağlı yönlendirme
    ));
}

// HTML formundaki JavaScript'i güncelle
add_action('wp_footer', function() {
    ?>
    <script>
    jQuery(document).ready(function($) {
        $('#apiKayitForm').on('submit', function(e) {
            e.preventDefault();
            
            if (!this.checkValidity()) {
                return false;
            }

            var form = $(this);
            var submitButton = form.find('button[type="submit"]');
            
            // Butonu devre dışı bırak
            submitButton.prop('disabled', true).html('Gönderiliyor...');

            $.ajax({
                url: '<?php echo admin_url('admin-ajax.php'); ?>',
                type: 'POST',
                data: {
                    action: 'api_kayit_form',
                    nonce: '<?php echo wp_create_nonce('api_kayit_nonce'); ?>',
                    firma_adi: $('#firma_adi').val(),
                    email: $('#email').val(),
                    website: $('#website').val(),
                    telefon: $('#telefon').val(),
                    aciklama: $('#aciklama').val()
                },
                success: function(response) {
                    if (response.success) {
                        // Başarılı mesajını göster
                        form.html('<div class="alert alert-success">' + 
                                response.data.message + '</div>');
                        
                        // İsteğe bağlı yönlendirme
                        if (response.data.redirect) {
                            setTimeout(function() {
                                window.location.href = response.data.redirect;
                            }, 2000);
                        }
                    } else {
                        // Hata mesajını göster
                        form.prepend('<div class="alert alert-danger">' + 
                                   response.data + '</div>');
                        submitButton.prop('disabled', false).html('Başvuru Yap');
                    }
                },
                error: function() {
                    form.prepend('<div class="alert alert-danger">' + 
                               'Bir hata oluştu. Lütfen daha sonra tekrar deneyin.</div>');
                    submitButton.prop('disabled', false).html('Başvuru Yap');
                }
            });
        });
    });
    </script>
    <?php
});